<?php
/* $Id: thai-tis-620.inc.php,v 2.75 2005/07/29 17:03:23 lem9 Exp $ */

// first created 2002/04/29 Arthit Suriyawongkul & Warit Wanasathian
// last modified 2004/08/22 Arthit Suriyawongkul

$charset = 'tis-620';
$text_dir = 'ltr';
$left_font_family = 'sans-serif';
$right_font_family = 'sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('亵', '亵', '亵', 'ԡ亵', '亵', 'ྵ亵', '͡亵');

$day_of_week = array('.', '.', '.', '.', '.', '.', '.');
$month = array('..', '..', '..', '..', '..', '..', '..', '..', '..', '..', '..', '..');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d %B %Y  %R.';

$timespanfmt = '%s ѹ, %s , %s ҷ, %s Թҷ';

$strAPrimaryKey = 'դ %s';
$strAbortedClients = '¡ԡ';
$strAbsolutePathToDocSqlDir = 'س absolute path ͧá docSQL ';
$strAccessDenied = '͹حҵҹ';
$strAction = 'зӡ';
$strAddAutoIncrement = ' AUTO_INCREMENT';
$strAddDeleteColumn = '/ź  (Ŵ)';
$strAddDeleteRow = '/ź ';
$strAddNewField = 'Ŵ';
$strAddPrivilegesOnDb = 'ԷԢͧҹŵ仹';
$strAddPrivilegesOnTbl = 'ԷԢͧҧ仹';
$strAddSearchConditions = '͹㹡ä:';
$strAddToIndex = 'Ѫդ %s';
$strAddUser = '';
$strAddUserMessage = 'º';
$strAddedColumnComment = ' ˵ Ѻ';
$strAddedColumnRelation = ' Ūѹ Ѻ';
$strAdministration = 'ôк';
$strAffectedRows = 'Ƿռ:';
$strAfter = 'ѧ %s';
$strAfterInsertBack = '觡Ѻ';
$strAfterInsertNewInsert = 'á¹';
$strAll = '';
$strAllTableSameWidth = 'ʴҧءѹ ¤ҧҡѹ?';
$strAlterOrderBy = '§㹵ҧ';
$strAnIndex = 'Ѫ %s';
$strAnalyzeTable = 'ҧ';
$strAnd = '';
$strAny = '';
$strAnyHost = 'ʵ';
$strAnyUser = '';
$strArabic = 'úԤ'; 
$strArmenian = '';
$strAscending = 'ҡ';
$strAtBeginningOfTable = 'ش鹢ͧҧ';
$strAtEndOfTable = 'شش¢ͧҧ';
$strAttr = '͵Ժǵ';
$strAutodetect = 'Ǩѵѵ';
$strAutomaticLayout = 'Ѵ˹ѵѵ';

$strBack = '͹Ѻ';
$strBaltic = 'ŵԡ';
$strBeginCut = 'شѴ';
$strBeginRaw = 'ŴԺ';
$strBinary = ' 亹 ';
$strBinaryDoNotEdit = ' 亹 -  ';
$strBookmarkDeleted = 'źӤ鹷訴º';
$strBookmarkLabel = 'ª';
$strBookmarkOptions = '͡';
$strBookmarkQuery = 'Ӥ鹹١';
$strBookmarkThis = 'Ӥ鹹';
$strBookmarkView = 'ҧ';
$strBrowse = 'Դ';
$strBulgarian = '';
$strBzError = 'phpMyAdmin öպѴ dump  ͧҡǹ Bz2  php 蹹. йҧáտ <code>$cfg[\'BZipDump\']</code> ͹ԡͧ phpMyAdmin  <code>FALSE</code>. Ҥسͧ÷öͧǹ¡úպѴ Bz2, سèѾô php 蹶Ѵ. ´ php bug report %s.';
$strBzip = '"bzipped"';

$strCSVOptions = '͡ CSV';
$strCalendar = 'ԷԹ';
$strCannotLogin = 'ö͡Թ MySQL ';
$strCantLoad = 'ö¡ǹ %s,<br />سҵǨͺõ駤Ңͧ PHP';
$strCantLoadRecodeIconv = 'ö¡Ǫ iconv  recode ŧشѡ, ҧ͡: 1) 駤 PHP öǪҹ  2) 駤 phpMyAdmin ͧŧشѡ';
$strCantRenameIdxToPrimary = '¹ʹѪ PRIMARY !';
$strCantUseRecodeIconv = 'öѧ iconv  libiconv  recode_string  ö¡Ǫ Ѻѧҹ鹢. ͧǨͺõ駤Ңͧ PHP';
$strCardinality = 'Cardinality';
$strCarriage = 'Ѵ: \\r';
$strCaseInsensitive = 'ʹ㨵硵˭';
$strCaseSensitive = 'ʹ㨵硵˭';
$strCentralEuropean = 'ûҧ';
$strChange = '¹';
$strChangeCopyMode = 'ҧ Է͹ѹ  ...';
$strChangeCopyModeCopy = '... 红ͧ.';
$strChangeCopyModeDeleteAndReload = ' ... źͧҨҡҧ ¡¡Էѧҡ.';
$strChangeCopyModeJustDelete = ' ... źͧҷ仨ҡҧ.';
$strChangeCopyModeRevoke = ' ... ¡׹Էҡ źѹѧҡ.';
$strChangeCopyUser = '¹͡Թ / Ҽ';
$strChangeDisplay = '͡Ŵͧʴ';
$strChangePassword = '¹ʼҹ';
$strCharset = 'شѡ';
$strCharsetOfFile = 'شѡТͧ (character set):';
$strCharsets = 'شѡ';
$strCharsetsAndCollations = 'شѡ С§ӴѺ';
$strCheckAll = '͡';
$strCheckPrivs = 'ǨͺԷ';
$strCheckPrivsLong = 'ǨͺԷѺҹ &quot;%s&quot;.';
$strCheckTable = 'Ǩͺҧ';
$strChoosePage = '͡˹ҷͧ';
$strColComFeat = 'ʴ˵آͧ';
$strCollation = '§ӴѺ';
$strColumnNames = 'ͤ';
$strColumnPrivileges = 'Է੾Ф';
$strCommand = '';
$strComments = '˵';
$strCompleteInserts = ' INSERT ٻẺ';
$strCompression = 'պѴ';
$strConfigFileError = 'phpMyAdmin öҹ͹ԡê蹢ͧس<br />» Ҩе PHP  öż (parse) <br />ͧ¡͹ԡê蹢µç (ԧҹҧ) д error message   ͧǨͺͧ quote  semicolon ú<br />Ҥس˹ҧ ʴҷءҧ繻Դ';
$strConfigureTableCoord = 'سҵ駤๵ͧҧ %s';
$strConnections = '';
$strCookiesRequired = 'ͧ͹حҵ \'ꡡ\' (cookie) ¡͹ ֧мҹش';
$strCopyTable = 'Ѵ͡ҧѧ (ҹ<b>.</b>ҧ):';
$strCopyTableOK =  'Ѵ͡ҧ %s 㹪 %s º.';
$strCopyTableSameNames = 'Ѵ͡ҧ价';
$strCouldNotKill = 'phpMyAdmin öô %s. ҧѹҨж١Դǡ.';
$strCreate = 'ҧ';
$strCreateIndex = 'ҧѪ¤ %s';
$strCreateIndexTopic = 'ҧѪ';
$strCreateNewDatabase = 'ҧҹ';
$strCreateNewTable = 'ҧҧ㹰ҹŹ %s';
$strCreatePage = '˹';
$strCreatePdfFeat = 'ҧ͡ PDF';
$strCriteria = '͹';
$strCroatian = '';
$strCyrillic = 'Ԥ';
$strCzech = '';
$strCzechSlovak = '-ѡ';

$strDBComment = '˵آͧҹ: ';
$strDBGContext = '͹硫';
$strDBGContextID = 'Ţ͹硫';
$strDBGHits = 'Ե';
$strDBGLine = '÷Ѵ';
$strDBGMaxTimeMs = 'ҡش, Թҷ';
$strDBGMinTimeMs = 'ҹش, Թҷ';
$strDBGModule = '';
$strDBGTimePerHitMs = '/Ե, Թҷ';
$strDBGTotalTimeMs = 'ҷ, Թҷ';
$strDBRename = '¹Ͱҹ';
$strDanish = 'ഹ';
$strData = '';
$strDataDict = 'ҹء';
$strDataOnly = '੾Т';
$strDatabase = 'ҹ';
$strDatabaseHasBeenDropped = '¹ҹ %s º';
$strDatabases = 'ҹ';
$strDatabasesDropped = '%s ҹ١º.';
$strDatabasesStats = 'ʶԵ԰ҹ';
$strDatabasesStatsDisable = '¡ԡʶԵ';
$strDatabasesStatsEnable = 'աʶԵ';
$strDatabasesStatsHeavyTraffic = 'ôҺ: ԴʶԵԢͧҹ Ҩзջҳö͹Ũӹǹҡ ҧ  MySQL.';
$strDbPrivileges = 'ԷШ੾аҹ';
$strDbSpecific = '੾аҹ';
$strDefault = 'һ';
$strDefragment = 'Ѵºҧ';
$strDelete = 'ź';
$strDeleteAndFlush = 'ź ¡¡Էѧҡ.';
$strDeleteAndFlushDescr = 'Ըշش ŴԷҹ еͧѡ.';
$strDeleted = 'źº';
$strDeletedRows = 'Ƿ١ź:';
$strDeleting = 'ѧź %s';
$strDescending = 'ҡ仹';
$strDescription = '´';
$strDictionary = 'ҹء';
$strDisabled = 'ЧѺ';
$strDisplayFeat = 'öҹʴ';
$strDisplayOrder = 'ӴѺʴ:';
$strDisplayPDF = 'ʴʡҢͧ PDF';
$strDoAQuery = ' "Ӥ鹨ҡҧ" (wildcard: "%")';
$strDoYouReally = 'ͧè ';
$strDocu = '͡ҧԧ';
$strDrop = '¹';
$strDropSelectedDatabases = '¹ҹŷ͡';
$strDropUsersDb = '¹ҹŷժǡѺ.';
$strDumpXRows = ' %s   %s';
$strDumpingData = 'dump ҧ';
$strDynamic = '褧';

$strEdit = '';
$strEditPDFPages = '˹ PDF';
$strEditPrivileges = 'Է';
$strEffective = 'ռ';
$strEmpty = 'ź';
$strEmptyResultSet = 'MySQL ׹ѾҧҡѺ (null / 0 ).';
$strEnabled = 'Դ';
$strEnd = 'ش';
$strEndCut = 'ششѴ';
$strEndRaw = 'شŴԺ';
$strEnglish = 'ѧ';
$strEnglishPrivileges = ' ôҺ: ͧ͢Է MySQL ʴѧ ';
$strError = 'ԴҴ';
$strEstonian = '';
$strExcelOptions = '͡ Excel';
$strExplain = '͸Ժ SQL';
$strExport = '͡';
$strExtendedInserts = 'á¹㹤';
$strExtra = '';

$strFailedAttempts = '';
$strField = 'Ŵ';
$strFieldHasBeenDropped = '¹Ŵ %s º';
$strFields = 'ӹǹŴ';
$strFieldsEmpty = ' ӹǹŴ ҧ! ';
$strFieldsEnclosedBy = 'Ŵ';
$strFieldsEscapedBy = 'ͧѺ escape char';
$strFieldsTerminatedBy = 'Ŵ';
$strFileCouldNotBeRead = 'ҹ';
$strFileNameTemplate = 'ٻẺͧ';
$strFileNameTemplateHelp = ' __DB__ ѺͰҹ, __TABLE__ Ѻ͵ҧ  ͡ %s strftime%s  Ѻк, ǹ¢ͧ (ʡ)ж١ѵѵ. ͤ ж١ѧ.';
$strFileNameTemplateRemember = 'ٻẺ';
$strFixed = '';
$strFlushTable = 'ҧҧ (flush)';
$strFormEmpty = 'Ẻ !';
$strFormat = 'ٻẺ';
$strFullText = '駢ͤ';
$strFunction = 'ѧ';

$strGenBy = 'ҧ';
$strGenTime = '㹡ҧ';
$strGeneralRelationFeat = 'öҹŪѹ';
$strGeorgian = '';
$strGerman = 'ѹ';
$strGlobal = 'ź';
$strGlobalPrivileges = 'ԷẺź';
$strGlobalValue = 'Ẻź';
$strGo = 'ŧ';
$strGrantOption = 'ͺԷ';
$strGreek = 'ա';
$strGzip = '"gzipped"';

$strHasBeenAltered = '¹';
$strHasBeenCreated = 'ҧ';
$strHaveToShow = 'ͧ͡ʴҧ˹觤';
$strHebrew = 'Ժ';
$strHexForBinary = 'ŢҹԺˡѺͧ亹';
$strHome = '˹Һҹ';
$strHomepageOfficial = 'ྨҧ繷ҧâͧ phpMyAdmin';
$strHost = 'ʵ';
$strHostEmpty = 'ʵѧҧ!';
$strHungarian = 'ѧ';

$strIcelandic = 'ͫŹ';
$strId = 'ID';
$strIdxFulltext = 'ͤ (fulltext)';
$strIfYouWish = 'ҵͧ¡ ੾кҧ кªͿŴҴ (Ъʹͧ١)';
$strIgnore = 'ʹ';
$strIgnoringFile = 'ʹ %s';
$strImportDocSQL = ' docSQL';
$strImportFiles = '';
$strImportFinished = '';
$strInUse = '';
$strIndex = 'Ѫ';
$strIndexHasBeenDropped = '¹Ѫ %s º';
$strIndexName = 'ʹѪ :';
$strIndexType = 'ԴͧѪ :';
$strIndexes = 'Ѫ';
$strInnodbStat = 'ʶҹТͧ InnoDB';
$strInsecureMySQL = 'ҡ纤ҡ˹ͧس سʼҹѺ root 觨ж١繪ͻ«ԷԾ.   MySQL ӧҹ¤һ¹ Ҩ١ءء سèѹѹ ͤʹ';
$strInsert = 'á';
$strInsertAsNewRow = 'á';
$strInsertNewRow = 'á';
$strInsertTextfiles = 'áŨҡͤ㹵ҧ';
$strInsertedRowId = 'áŢШ:';
$strInsertedRows = 'Ƿ١á:';
$strInstructions = 'Ը';
$strInternalRelations = 'Ūѹ';

$strJapanese = '';
$strJumpToDB = 'ⴴ价ҹ &quot;%s&quot;.';
$strJustDelete = 'ź͡ҡҧʴԷҶ֧';

$strKeepPass = 'س¹ʼҹ';
$strKeyname = 'ͤ';
$strKill = 'ҷ';
$strKorean = '';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = '͡ LaTeX';
$strLandscape = 'ǹ͹';
$strLatexCaption = '͸Ժµҧ';
$strLatexContinued = '()';
$strLatvian = 'ѵ';
$strLengthSet = '/૵*';
$strLimitNumRows = '¹˹';
$strLineFeed = '鹺÷Ѵ: \\n';
$strLinesTerminatedBy = 'Ǵ';
$strLinkNotFound = '辺ԧ';
$strLinksTo = 'ѧ';
$strLithuanian = 'Ը';
$strLoadMethod = 'Ըա LOAD';
$strLocalhost = 'Ť';
$strLocationTextfile = 'ͤ͡ҡ';
$strLogPassword = 'ʼҹ:';
$strLogServer = '';
$strLogUsername = 'ͼ:';
$strLogin = 'к';
$strLoginInformation = '͡Թ';
$strLogout = '͡ҡк';

$strMIME_MIMEtype = 'MIME-type';
$strMIME_available_mime = 'MIME-types ';
$strMIME_available_transform = 'ŧ¡';
$strMIME_description = '´';
$strMIME_nodescription = 'ҡ´Ѻŧ.<br />سͺ¹,  %s .';
$strMIME_transformation_options = '͡ŧ';
$strMaximumSize = 'Ҵ˭ش: %s%s';
$strModifications = 'ѹ֡º';
$strModify = '';
$strModifyIndexTopic = '䢴Ѫ';
$strMoreStatusVars = 'More status variables';
$strMoveTable = 'µҧ (database<b>.</b>table):';
$strMoveTableOK = 'ҧ %s ١ %s ';
$strMoveTableSameNames = 'µҧ价';
$strMultilingual = '';
$strMySQLCharset = 'شѡ (charset) ͧ MySQL';
$strMySQLReloaded = '¡ MySQL ';
$strMySQLSaid = 'MySQL ʴ: ';
$strMySQLServerProcess = 'MySQL %pma_s1% ӧҹ躹 %pma_s2% 㹪 %pma_s3%';
$strMySQLShowProcess = 'ʴҹͧ MySQL';
$strMySQLShowStatus = 'ʴʶҹТͧ MySQL';
$strMySQLShowVars = 'ʴкͧ MySQL';

$strName = '';
$strNext = '';
$strNo = '';
$strNoDatabases = 'հҹ';
$strNoDatabasesSelected = 'ѧ͡ҹ.';
$strNoDescription = '´';
$strNoDropDatabases = ' "DROP DATABASE" ١Դ';
$strNoExplain = 'ͧ͸Ժ SQL';
$strNoFrames = '<b></b> Ъ phpMyAdmin ¢';
$strNoIndex = 'ѧ˹Ѫ!';
$strNoIndexPartsDefined = '˹ǹ ͧѪ!';
$strNoModification = 'ա¹ŧ';
$strNoOptions = 'ٻẺյ͡';
$strNoPassword = 'ʼҹ';
$strNoPhp = ' PHP';
$strNoPrivileges = 'Է';
$strNoQuery = 'դӤ SQL!';
$strNoRights = 'سԷԷҵç!';
$strNoRowsSelected = 'ѧ͡';
$strNoTablesFound = '辺ҧ  㹰ҹ';
$strNoUsersFound = '辺.';
$strNoValidateSQL = 'ͧǨͺ SQL';
$strNone = '';
$strNotNumber = 'ҹŢ!';
$strNotOK = '赡ŧ';
$strNotSet = '辺ҧ <b>%s</b>  %s';
$strNull = 'ҧ (null)';
$strNumSearchResultsInTable = ' %s Ѿç㹵ҧ <i>%s</i>';
$strNumSearchResultsTotal = '<b>:</b> <i>%s</i> Ѿç';
$strNumTables = 'ҧ';

$strOK = 'ŧ';
$strOftenQuotation = '»ԨͧѭС (ͧ¤Ӿٴ)<br />"ҷ" ¶֧ ͧ¤ ੾СѺŴ쪹Դ char  varchar ҹ';
$strOperations = 'кǹ';
$strOptimizeTable = 'Ѻ觵ҧ';
$strOptionalControls = '˹Ҩ¹ ҹѡо ҧ';
$strOptionally = 'ҷ';
$strOr = '';
$strOverhead = 'Թ';
$strOverwriteExisting = '¹Ѻ';

$strPHP40203 = 'سѧ PHP  4.2.3, պçǡѺ multi-byte strings (mbstring). سҴ§ҹ PHP Ţ 19404. йس PHP 蹹Ѻ phpMyAdmin.';
$strPHPVersion = '蹢ͧ PHP';
$strPageNumber = 'Ţ˹:';
$strPaperSize = 'Ҵд';
$strPartialText = 'ͤҧǹ';
$strPassword = 'ʼҹ';
$strPasswordChanged = '¹ʼҹͧ %s º';
$strPasswordEmpty = 'ʼҹѧҧ!';
$strPasswordNotSame = 'ʼҹçѹ!';
$strPdfDbSchema = 'schema ͧҹ "%s" - ˹ %s';
$strPdfInvalidTblName = 'յҧ "%s"!';
$strPdfNoTables = 'յҧ';
$strPerHour = 'ͪ';
$strPerMinute = '͹ҷ';
$strPerSecond = 'Թҷ';
$strPhoneBook = 'شѾ';
$strPhp = 'ҧ PHP';
$strPmaDocumentation = '͡á phpMyAdmin';
$strPmaUriError = '<b>ͧ</b>˹ <tt>$cfg[\'PmaAbsoluteUri\']</tt> ͹ԡê¡͹';
$strPolish = 'Ź';
$strPortrait = 'ǵ';
$strPos1 = 'ش';
$strPrevious = '͹˹';
$strPrimary = '';
$strPrimaryKeyHasBeenDropped = '¹դº';
$strPrimaryKeyName = 'ͧ͢դ еͧ PRIMARY ҹ';
$strPrimaryKeyWarning = '(ͧ͢դ<b>еͧ</b> "PRIMARY" ҹ!)';
$strPrint = '';
$strPrintView = 'ʴ';
$strPrivDescAllPrivileges = 'ԷԷءҧ ¡鹡Է (GRANT).';
$strPrivDescAlter = '͹حҵ¹çҧͧҧ.';
$strPrivDescCreateDb = '͹حҵҧҹ еҧ.';
$strPrivDescCreateTbl = '͹حҵҧҧ.';
$strPrivDescCreateTmpTable = '͹حҵҧҧǤ.';
$strPrivDescDelete = '͹حҵź';
$strPrivDescDropDb = '͹حҵ駰ҹ еҧ';
$strPrivDescDropTbl = '͹حҵ駵ҧ';
$strPrivDescExecute = '͹حҵѹ stored procedure (ռ MySQL 蹹)';
$strPrivDescFile = '͹حҵҢ ͡ 价';
$strPrivDescGrant = '͹حҵ ԷҶ֧ ͧ¡ҧԷ';
$strPrivDescIndex = '͹حҵҧ з Ѫ';
$strPrivDescInsert = '͹حҵ ᷹ ';
$strPrivDescLockTables = '͹حҵ͡ҧѺôѨغѹ';
$strPrivDescMaxConnections = 'ӡѴӹǹ öԴ ͪ';
$strPrivDescMaxQuestions = 'ӡѴӹǹͧӤ öҷ ͪ';
$strPrivDescMaxUpdates = 'ӡѴӹǹͧ ¹ŧҧ Ͱҹ ö ͪ';
$strPrivDescProcess3 = '͹حҵʢͧ';
$strPrivDescProcess4 = '͹حҵ٤Ӥ鹷¡';
$strPrivDescReferences = 'ռ MySQL 蹹';
$strPrivDescReload = '͹حҵ¡ҡ˹ͧ ҧᤪͧ';
$strPrivDescReplClient = 'ͺԷ 㹡ö slaves  masters ˹.';
$strPrivDescSelect = '͹حҵҹ.';
$strPrivDescShowDb = 'ö¡¡ðҹŷ';
$strPrivDescShutdown = '͹حҵԴ';
$strPrivDescUpdate = '͹حҵ¹.';
$strPrivDescUsage = 'Է.';
$strPrivileges = 'Է';
$strPrivilegesReloaded = 'Է١¡º';
$strProcesslist = '¡';
$strPutColNames = 'ͿŴá';

$strQBE = 'Ӥ鹨ҡҧ';
$strQBEDel = 'ź';
$strQBEIns = '';
$strQueryFrame = '˹ҵҧӤ';
$strQueryOnDb = 'Ӥ鹺ҹ <b>%s</b>:';
$strQuerySQLHistory = 'SQL-history';
$strQueryStatistics = '<b>ʶԵԤӤ</b>:  %s Ӥ ١价 Ѻк.';
$strQueryTime = 'Ӥ %01.4f Թҷ';
$strQueryType = 'ԴӤ';

$strReType = '';
$strReceived = 'Ѻ';
$strRecords = '¹';
$strReferentialIntegrity = 'Ǩͺóͧҧ֧:';
$strRefresh = '¡';
$strRelationNotWorking = 'öѺ linked Tables ١ЧѺ ˵ؼŷ %shere%s';
$strRelationView = 'ͧŪѹ';
$strRelationalSchema = 'Ūѹ ʡ';
$strRelations = 'Ūѹ';
$strReloadFailed = 'Ŵ MySQL ';
$strReloadMySQL = 'Ŵ MySQL ';
$strReloadingThePrivileges = 'ѺاԷҶ֧աͺ';
$strRemoveSelectedUsers = '͹͡';
$strRenameTable = '¹͵ҧ';
$strRenameTableOK = 'ҧ %s ١¹ %s';
$strRepairTable = 'ҧ';
$strReplace = '¹Ѻ';
$strReplaceNULLBy = '᷹ NULL ';
$strReplaceTable = '¹Ѻ¢Ũҡ';
$strReset = '';
$strResourceLimits = 'մӡѴͧѾҡ';
$strRevoke = 'ԡ͹';
$strRevokeAndDelete = 'ԡ͹ active privileges ҡ źѧҡ.';
$strRevokeAndDeleteDescr = 'ҧ ѧԷ USAGE  Է ж١¡ա.';
$strRevokeMessage = 'سԡ͹ԷԢͧ %s';
$strRomanian = '';
$strRowLength = '';
$strRowSize = ' Ҵ ';
$strRows = '';
$strRowsFrom = ' ҡǷ';
$strRowsModeFlippedHorizontal = 'ǹ͹ (عͧ)';
$strRowsModeHorizontal = 'ǹ͹';
$strRowsModeOptions = ' %s ЫǷء %s ';
$strRowsModeVertical = 'ǵ';
$strRowsStatistic = 'ʶԵԢͧ';
$strRunQuery = 'żŤӤ';
$strRunSQLQuery = 'żŤӤ鹺ҹ %s';
$strRunning = 'ӧҹ躹 %s';
$strRussian = '';

$strSQL = 'SQL';
$strSQLOptions = '͡ SQL';
$strSQLParserBugMessage = 'Ҩա¹ŧҧҧ سѹ繢ͼԴҴͧҹ SQL. سҵǨͺӤ鹢ͧسǹ ੾СԴ/Դͧ¤Ӿٴ (quotes) ١ͧ. ա˵˹觷 سҨѾŴ亹բҧ͡ǧͧͧ¤Ӿٴ. سöͧӤ鹢ͧسҹŹͧ MySQL 觤سҨоͼԴҴҧҧ㹹. ҡ MySQL 駢ͼԴҴ, ͧҹ ѹҨЪسԹԨ»ѭբ. ҤسѧѭҡѺ parser  phpMyAdmin  辺ѭҡѺ parser 㹤ҹŹ, ͧŴǢͧӤ SQL ŧ зͤӤ SQL  ѧԴѭա, 駢ͼԴҴѧҷ, ѹҾѺǢŷس ҡǹͧ CUT ҹҧ.';
$strSQLParserUserError = 'ҨբͼԴҴҧҧ㹤Ӥ SQL ͧس. ҡ MySQL server 駢ͼԴҴҴҹҧ ͧҹ ѹҨЪسԹԨ»ѭբ';
$strSQLQuery = 'Ӥ SQL';
$strSQLResult = 'Ѿ SQL';
$strSQPBugInvalidIdentifer = '͵١ͧ';
$strSQPBugUnclosedQuote = 'Դͧ¤Ӿٴ';
$strSQPBugUnknownPunctuation = 'ͧä͹ѡ';
$strSave = 'ѹ֡';
$strScaleFactorSmall = 'ѵ͹Թ ШѴʡ˹';
$strSearch = '';
$strSearchFormTitle = '㹰ҹ';
$strSearchInTables = '㹵ҧ:';
$strSearchNeedle = '  ҷͧä (wildcard: "%"):';
$strSearchOption1 = 'ҧ˹觤';
$strSearchOption2 = 'ء';
$strSearchOption3 = '͹';
$strSearchOption4 = 'ٻẺӾͧ (regular expression)';
$strSearchResultsFor = 'šä "<i>%s</i>" %s:';
$strSearchType = ':';
$strSelectADb = 'ô͡ҹ';
$strSelectAll = '͡';
$strSelectFields = '͡Ŵ (ҧ˹觿Ŵ):';
$strSelectNumRows = '㹤Ӥ';
$strSelectTables = '͡ҧ';
$strSend = '';
$strSent = '١';
$strServer = '';
$strServerChoice = '͡';
$strServerNotResponding = 'ѧͺʹͧ';
$strServerStatus = 'ѹ';
$strServerStatusUptime = ' MySQL ѹ %s. ͹ %s.';
$strServerTabProcesslist = '';
$strServerTabVariables = '';
$strServerTrafficNotes = '<b>èҨâͧ</b>: ҧʴʶԵԢͧèҨú͢ Ѻ MySQL  ѹӧҹ.';
$strServerVars = ' Фҡ˹ ͧ';
$strServerVersion = '蹢ͧ';
$strSessionValue = 'ʪ';
$strSetEnumVal = 'ҪԴͧŴ "enum"  "set" ôҵٻẺ: \'a\',\'b\',\'c\'...<br />ҵͧͧ backslash ("\\")  ѭС ("\'") 㹤ҹ ͧ Ū ˹ (ҧ: \'\\\\xyz\' or \'a\\\'b\')';
$strShow = 'ʴ';
$strShowAll = 'ʴ';
$strShowColor = 'ʴ';
$strShowDatadictAs = 'ٻẺҹء';
$strShowFullQueries = 'ʴӤẺ';
$strShowGrid = 'ʴԴ';
$strShowPHPInfo = 'ʴŢͧ PHP';
$strShowTableDimension = 'ʴԵԢͧҧ';
$strShowTables = 'ʴҧ';
$strShowThisQuery = ' ʴӤ鹹ա ';
$strShowingRecords = 'ʴ¹ ';
$strSimplifiedChinese = 'չ (蹴Թ˭)';
$strSingly = '()';
$strSize = 'Ҵ';
$strSlovak = 'ѡ';
$strSlovenian = '';
$strSort = '§';
$strSortByKey = '§¤';
$strSpaceUsage = 'ͷ';
$strSpanish = '໹';
$strSplitWordsWithSpace = 'Ӷ١觴ªͧҧ (" ").';
$strStatCheckTime = 'Ǩͺش';
$strStatCreateTime = 'ҧ';
$strStatUpdateTime = 'Ѻاش';
$strStatement = '';
$strStatus = 'ʶҹ';
$strStrucCSV = ' CSV (蹴ͧ١ ",")';
$strStrucData = 'çҧТ';
$strStrucDrop = ' DROP TABLE';
$strStrucExcelCSV = ' CSV ѺëͿ';
$strStrucOnly = '੾çҧ';
$strStructPropose = 'ʹçҧҧ';
$strStructure = 'çҧ';
$strSubmit = '';
$strSuccess = 'ӤӤº';
$strSum = '';
$strSwedish = 'ഹ';
$strSwitchToTable = 'Ѻ价ҧ١';

$strTable = 'ҧ ';
$strTableComments = '˵آͧҧ';
$strTableEmpty = '͵ҧѧҧ!';
$strTableHasBeenDropped = '¹ҧ %s º';
$strTableHasBeenEmptied = 'ź㹵ҧ %s º';
$strTableHasBeenFlushed = 'ҧҧ %s º';
$strTableMaintenance = 'ôѡҵҧ';
$strTableOfContents = 'úѭ';
$strTableOptions = '͡ҧ';
$strTableStructure = 'çҧҧ';
$strTableType = 'Դҧ';
$strTables = '%s ҧ';
$strTblPrivileges = 'ԷШ੾еҧ';
$strTextAreaLength = 'ͧҡǢͧѹ <br />Ŵ Ҩ';
$strThai = '';
$strTheContent = 'á ҡͧسº';
$strTheContents = 'ѺǷդ  unique key ͹ѹ Ҩҡ ᷹㹵ҧ';
$strTheTerminator = 'ششͧŴ';
$strTheme = '˹ҵ';
$strThisHost = 'ʵ';
$strThisNotDirectory = 'á';
$strThreadSuccessfullyKilled = 'ô %s ١º.';
$strTime = '';
$strTotal = '';
$strTotalUC = '';
$strTraditionalChinese = 'չ (ѹ)';
$strTraditionalSpanish = '໹ ()';
$strTraffic = 'èҨ';
$strTransformation_image_jpeg__inline = 'ʴٻҴ硷衴仴Ҿ˭; ͡: ҧ, ٧ ˹繾ԡ (Ѵǹ)';
$strTransformation_image_jpeg__link = 'ʴԧѧٻ (ǹŴ亹µç/blob).';
$strTransformation_image_png__inline = 'ٻԴ image/jpeg ѹ';
$strTransformation_text_plain__formatted = 'ʧǹèѴٻẺ㹿Ŵ -- á escape character.';
$strTruncateQueries = 'Ѵ͹Ӥ鹷ʴ';
$strTurkish = 'á';
$strType = 'Դ';

$strUkrainian = 'ù';
$strUncheckAll = '͡';
$strUnicode = 'ٹ';
$strUnique = '͡ѡɳ';
$strUnknown = 'к';
$strUnselectAll = '͡';
$strUpdComTab = 'ôҹ͡ǡѺ ԸաûѺاҧ Column_comments (˵آͧ) ͧس';
$strUpdatePrivMessage = 'سѺاԷѺ %s ';
$strUpdateProfileMessage = 'Ѻاº';
$strUpdateQuery = 'ѺاӤ';
$strUsage = 'ҹ';
$strUseBackquotes = ' \'backqoute\' Ѻ͵ҧпŴ';
$strUseTables = 'ҧ';
$strUseTextField = 'ͧͤ (text field)';
$strUseThisValue = 'ҹ';
$strUser = '';
$strUserAlreadyExists = 'ռ %s !';
$strUserEmpty = 'ͼѧҧ!';
$strUserName = 'ͼ';
$strUserNotFound = '辺͡㹵ҧʴԷ';
$strUserOverview = 'ŷ仢ͧ';
$strUsersDeleted = 'ź͡º.';
$strUsersHavingAccessToDb = 'ԷҶ֧ҹ &quot;%s&quot;';

$strValidateSQL = 'Ǩͺ SQL';
$strValidatorError = 'öǵǨͺ SQL . سҵǨͺ سԴ php extensions  ѧ͸Ժ %sdocumentation%s º';
$strValue = '';
$strVar = '';
$strViewDump = 'çҧͧҧ';
$strViewDumpDB = 'çҧͧҹ';

$strWebServerUploadDirectory = 'áѺѾŴ ';
$strWebServerUploadDirectoryError = 'öҹ áշѺѾŴ';
$strWelcome = '%s Թյ͹Ѻ';
$strWestEuropean = 'ûѹ';
$strWildcard = '';
$strWithChecked = 'ӡѺ͡:';
$strWritingCommentNotPossible = '¹˵ع';
$strWritingRelationNotPossible = '¹Ūѹ';
$strWrongUser = '͹حҵ ͼʼҹԴ';

$strXML = 'XML';

$strYes = '';

$strZeroRemovesTheLimit = 'ôҺ: ¹ҹ 0 (ٹ) ¶֧ բմӡѴ.';
$strZip = '"١պѴ (zip)"';

// To translate:
$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
$strAddConstraints = 'Add constraints';  //to translate
$strAddDropDatabase = 'Add DROP DATABASE';//to translate
$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
$strAddIntoComments = 'Add into comments';//to translate
$strAfterInsertSame = 'Go back to this page';  //to translate

$strBookmarkAllUsers = 'Let every user access this bookmark';  //to translate
$strBrowseForeignValues = 'Browse foreign values';  //to translate

$strCheckOverhead = 'Check tables with overhead';  //to translate
$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
$strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
$strConstraintsForTable = 'Constraints for table';  //to translate
$strCreationDates = 'Creation/Update/Check dates';  //to translate

$strDatabaseEmpty = 'The database name is empty!';  //to translate
$strDatabaseExportOptions = 'Database export options';//to translate
$strDatabaseNoTable = 'This database contains no table!';//to translate
$strDefaultValueHelp = 'For default values, please enter just a single value, without backslash escaping or quotes, using this format: a';  //to translate
$strDelOld = 'The current Page has References to Tables that no longer exist. Would you like to delete those References?';  //to translate
$strDelayedInserts = ' delayed inserts';  //to translate
$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
$strDumpSaved = 'Dump has been saved to file %s.';  //to translate

$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
$strExcelEdition = 'Excel edition';  //to translate
$strExecuteBookmarked = 'Execute bookmarked query';  //to translate

$strFileAlreadyExists = 'File %s already exists on server, change filename or check overwrite option.';  //to translate
$strFlushPrivilegesNote = 'ôҺ: phpMyAdmin gets the users\' privileges directly from MySQL\'s privilege tables. The content of this tables may differ from the privileges the server uses if manual changes have made to it. In this case, you should %sreload the privileges%s before you continue.'; //to translate

$strIgnoreInserts = 'Use ignore inserts';  //to translate
$strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.';  //to translate

$strJustDeleteDescr = 'The &quot;deleted&quot; users will still be able to access the server as usual until the privileges are reloaded.'; //to translate

$strLatexContent = 'Content of table __TABLE__';//to translate
$strLatexContinuedCaption = 'Continued table caption';//to translate
$strLatexIncludeCaption = 'Include table caption';//to translate
$strLatexLabel = 'Label key';//to translate
$strLatexStructure = 'Structure of table __TABLE__';//to translate
$strLoadExplanation = 'The best method is checked by default, but you can change if it fails.';  //to translate

$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
$strMIME_transformation = 'Browser transformation';//to translate
$strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s';//to translate
$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
$strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';//to translate
$strMustSelectFile = 'You should select file which you want to insert.';  //to translate
$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate

$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
$strNoPermission = 'The web server does not have permission to save the file %s.';  //to translate
$strNoSpace = 'Insufficient space to save the file %s.';  //to translate

$strOperator = 'Operator';  //to translate

$strPrintViewFull = 'Print view (with full texts)';  //to translate
$strPrivDescReplSlave = 'Needed for the replication slaves.'; //to translate
$strPrivDescSuper = '͹حҵ, Ҩӹǹͨж֧дѺ٧ش; Required for most administrative operations like setting global variables or killing threads of other users.'; //to translate

$strQueryWindowLock = 'Do not overwrite this query from outside the window';  //to translate

$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate

$strSQLExportType = 'Export type';  //to translate
$strSaveOnServer = 'Save on server in %s directory';  //to translate
$strSecretRequired = 'The configuration file now needs a secret passphrase (blowfish_secret).';  //to translate
$strStrucNativeExcel = ' Native MS Excel';  //to translate

$strTakeIt = 'take it';  //to translate
$strToggleScratchboard = 'toggle scratchboard';  //to translate
$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';//to translate
$strTransformation_text_plain__external = 'Ѻ չء ҹ: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';//to translate
$strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';  //to translate
$strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.';  //to translate
$strTransformation_text_plain__substr = 'ʴͤҧǹҹ. First option is an offset to define where the output of your text starts (Default 0). Second option is an offset how much text is returned. If empty, returns all the remaining text. The third option defines which chars will be appended to the output when a substring is returned (Default: ...) .';//to translate

$strUpgrade = 'You should upgrade to %s %s or later.';  //to translate
$strUseHostTable = ' Host Table';  //to translate

$strViewDumpDatabases = 'View dump (schema) of databases';//to translate

$strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings';  //to translate

$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strRoutines = 'Routines';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
?>
